package cd.casic.ci.common.pipeline.pojo.setting;

import io.swagger.v3.oas.annotations.media.Schema;
import lombok.Getter;

/**
 * @Author：mianbin
 * @Package：cd.casic.ci.common.pipeline.pojo.setting
 * @Project：ops-pro
 * @name：PipelineRunLockType
 * @Date：2025/03/26 14:14
 * @Filename：PipelineRunLockType
 * @description：Todo
 */
@Getter
@Schema(title = "流水线运行锁定方式")
public enum PipelineRunLockType {
    @Schema(title = "可同时运行多个构建任务（默认）")
    MULTIPLE,
    @Schema(title = "同一时间最多只能运行一个构建任务")
    SINGLE,
    @Schema(title = "最多只能运行一个构建任务，且失败时锁定")
    SINGLE_LOCK,
    @Schema(title = "锁定流水线，任何触发方式都无法运行")
    LOCK,
    @Schema(title = "并发组锁定，项目级别，同一组的构建为SINGLE模式")
    GROUP_LOCK;

    /**
     * 注意，数字与枚举的ordinal不一样，ordinal是下标为0开始 ，而这以1为开始
     */
    public static int toValue(PipelineRunLockType type) {
        return switch (type) {
            case MULTIPLE -> 1;
            case SINGLE -> 2;
            case SINGLE_LOCK -> 3;
            case LOCK -> 4;
            case GROUP_LOCK -> 5;
        };
    }

    public static PipelineRunLockType valueOf(int value) {
        return switch (value) {
            case 1 -> MULTIPLE;
            case 2 -> SINGLE;
            case 3 -> SINGLE_LOCK;
            case 4 -> LOCK;
            case 5 -> GROUP_LOCK;
            default -> MULTIPLE;
        };
    }
}

