package cd.casic.ci.process.engine.worker;

import org.apache.http.conn.ssl.NoopHostnameVerifier;
import org.apache.http.conn.ssl.TrustSelfSignedStrategy;
import org.apache.http.impl.client.CloseableHttpClient;
import org.apache.http.impl.client.HttpClients;
import org.apache.http.ssl.SSLContextBuilder;
import org.springframework.http.client.HttpComponentsClientHttpRequestFactory;
import org.springframework.web.client.RestTemplate;

import javax.net.ssl.SSLContext;
import java.security.KeyManagementException;
import java.security.KeyStoreException;
import java.security.NoSuchAlgorithmException;

/**
 * @author HopeLi
 * @version v1.0
 * @ClassName httpWorker
 * @Date: 2025/5/21 20:13
 * @Description:
 */
public abstract class HttpWorker extends BaseWorker{
    public static RestTemplate getRestTemplateWithoutSANCheck() throws NoSuchAlgorithmException, KeyManagementException, KeyStoreException {
        // 创建一个信任所有证书的 SSL 上下文
        SSLContext sslContext = new SSLContextBuilder()
                .loadTrustMaterial(null, new TrustSelfSignedStrategy())
                .build();

        // 创建一个不验证主机名的主机名验证器
        CloseableHttpClient httpClient = HttpClients.custom()
                .setSSLContext(sslContext)
                .setSSLHostnameVerifier(NoopHostnameVerifier.INSTANCE)
                .build();

        // 创建一个自定义的请求工厂
        HttpComponentsClientHttpRequestFactory requestFactory = new HttpComponentsClientHttpRequestFactory();
        requestFactory.setHttpClient(httpClient);

        return new RestTemplate(requestFactory);
    }

    public static void main(String[] args) {
        try {
            RestTemplate restTemplate = getRestTemplateWithoutSANCheck();
            // 示例 POST 请求
            String url = "https://175.6.27.252:30002/openapi/v1/sbom/detect-file";
            String requestBody = "{\"key\": \"value\"}";
            String response = restTemplate.postForObject(url, requestBody, String.class);
            System.out.println("Response: " + response);
        } catch (Exception e) {
            e.printStackTrace();
        }
    }
}
