package cd.casic.ci.log.scm.service.scm;


import cd.casic.ci.log.scm.dal.pojo.oauth.GitToken;
import cd.casic.framework.commons.util.http.OkhttpUtils;
import cd.casic.ci.log.scm.config.GitConfig;
import com.fasterxml.jackson.databind.ObjectMapper;
import jakarta.annotation.Resource;
import lombok.extern.slf4j.Slf4j;
import okhttp3.*;
import org.springframework.stereotype.Service;

import java.io.IOException;

@Service
@Slf4j
public class GitServiceImpl implements IGitService {

    @Resource
    private GitConfig gitConfig;

    @Resource
    private ObjectMapper objectMapper;

    @Override
    public GitToken refreshToken(String userId, GitToken accessToken) {
        log.info("Start to refresh the token of user {}", userId);
        long startEpoch = System.currentTimeMillis();
        try {
            String url = gitConfig.gitUrl + "/oauth/token" +
                    "?client_id=" + gitConfig.clientId +
                    "&client_secret=" + gitConfig.clientSecret +
                    "&grant_type=refresh_token" +
                    "&refresh_token=" + accessToken.getRefreshToken() +
                    "&redirect_uri=" + gitConfig.gitHookUrl;
            Request request = new Request.Builder()
                    .url(url)
                    .post(RequestBody.create(MediaType.parse("application/x-www-form-urlencoded;charset=utf-8"), ""))
                    .build();
            Response response = OkhttpUtils.doHttp(request);
            ResponseBody body = response.body();
            assert body != null;
            return objectMapper.readValue(body.string(), GitToken.class);
        } catch (IOException e) {
            e.printStackTrace();
        } finally {
            log.info("It took {}ms to refresh the token", System.currentTimeMillis() - startEpoch);
        }
        return null;
    }
}
